@@ -31,7 +31,7 @@ class Configuration(object):
 
     If you are using Google App Engine, you must use unsafe ssl [1]_::
 
-        The proxy the URL Fetch servicr uses cannot authenticate the host it
+        The proxy the URL Fetch service uses cannot authenticate the host it
         is contacting. Because there is no certificate trust chain, the proxy
         accepts all certificates, including self-signed certificates. The
         proxy server cannot detect "man in the middle" attacks between App
@@ -40,12 +40,13 @@ class Configuration(object):
 .. [1] `URL Fetch Python API Overview <https://developers.google.com/appengine/docs/python/urlfetch/overview>`_
     """
     @staticmethod
-    def configure(environment, merchant_id, public_key, private_key):
+    def configure(environment, merchant_id, public_key, private_key, http_strategy=None):
         Configuration.environment = environment
         Configuration.merchant_id = merchant_id
         Configuration.public_key = public_key
         Configuration.private_key = private_key
         Configuration.use_unsafe_ssl = False
+        Configuration.default_http_strategy = http_strategy
 
     @staticmethod
     def gateway():
@@ -54,22 +55,27 @@ class Configuration(object):
     @staticmethod
     def instantiate():
         return Configuration(
-            Configuration.environment,
-            Configuration.merchant_id,
-            Configuration.public_key,
-            Configuration.private_key
+            environment=Configuration.environment,
+            merchant_id=Configuration.merchant_id,
+            public_key=Configuration.public_key,
+            private_key=Configuration.private_key,
+            http_strategy=Configuration.default_http_strategy
         )
 
     @staticmethod
     def api_version():
         return "3"
 
-    def __init__(self, environment, merchant_id, public_key, private_key):
+    def __init__(self, environment, merchant_id, public_key, private_key, http_strategy=None):
         self.environment = environment
         self.merchant_id = merchant_id
         self.public_key = public_key
         self.private_key = private_key
-        self._http_strategy = self.__determine_http_strategy()
+
+        if http_strategy:
+            self._http_strategy = http_strategy(self, self.environment)
+        else:
+            self._http_strategy = self.__determine_http_strategy()
 
     def base_merchant_path(self):
         return "/merchants/" + self.merchant_id
